The GNAT Components Collection (GNATCOLL) - Postgres
====================================================

This component provides support for parsing the .ali and .gli files that
are generated by GNAT and gcc. In particular, those files contain
information that can be used to do cross-references for entities (going
from references to their declaration for instance).

A typical example would be:

declare
   Session : Session_Type;
begin
   GNATCOLL.SQL.Sessions.Setup
      (Descr   => GNATCOLL.SQL.Sqlite.Setup (":memory:"));
   Session := Get_New_Session;

   ... parse the project through GNATCOLL.Projects

   Create_Database (Session.DB);
   Parse_All_LI_Files (Session, ...);
 end;

Dependencies
------------

This component requires the following external components, that should be
available on your system:

- gprbuild
- gnatcoll-core
- gnatcoll-iconv
- gnatcoll-sqlite

Configuring the build process
-----------------------------

The following variables can be used to configure the build process:

General:

   prefix     : location of the installation, the default is the running
                GNAT installation root.

   BUILD      : control the build options : PROD (default) or DEBUG

   PROCESSORS : parallel compilation (default is 0, which uses all available
                cores)

   TARGET     : for cross-compilation, auto-detected for native platforms

   SOURCE_DIR : for out-of-tree build

   INTEGRATED : treat prefix as compiler installation (yes/no)
                this is so that installed gnatcoll project can later be
                referenced as predefined project of this compiler;
                this adds a normalized target subdir to prefix
                default is "no"

To use the default options:

   $ make setup

Building
--------

The component is built using a standalone GPR project file.

However, to build all versions of the library (static, relocatable and
static-pic) it is simpler to use the provided Makefile:

$ make

Then, to install it:

$ make install


Bug reports
-----------

Please send questions and bug reports to report@adacore.com following
the same procedures used to submit reports with the GNAT toolset itself.
